#ifndef TYPEDEF_H
#define TYPEDEF_H

typedef unsigned int   Trixel;
typedef unsigned short BufNum;

#endif
